<?php declare(strict_types=1);

namespace App\Test\Controller;

use App\Entity\FoodOrder;
use App\Tests\DbWebTest;
use Override;

use function sprintf;

final class FoodOrderControllerTest extends DbWebTest
{
    private string $path = '/food/order/';

    #[Override]
    public function getEntityClass(): string
    {
        return FoodOrder::class;
    }

    public function testIndex(): void
    {
        $this->client->request('GET', $this->path);

        self::assertResponseStatusCodeSame(200);
        self::assertPageTitleContains('FoodOrder index');

        // Use the $crawler to perform additional assertions e.g.
        // self::assertSame('Some text on the page', $crawler->filter('.p')->first());
    }

    public function testNew(): void
    {
        $this->markTestIncomplete();
        $this->client->request('GET', sprintf('%snew', $this->path));

        self::assertResponseStatusCodeSame(200);

        $this->client->submitForm('Save', [
            'food_order[createdAt]' => 'Testing',
            'food_order[closedAt]' => 'Testing',
            'food_order[foodVendor]' => 'Testing',
        ]);

        self::assertResponseRedirects($this->path);

        self::assertSame(1, $this->repository->count([]));
    }

    public function testShow(): void
    {
        $this->markTestIncomplete();
        $fixture = new FoodOrder;
        $fixture->setCreatedAt('My Title');
        $fixture->setClosedAt('My Title');
        $fixture->setFoodVendor('My Title');

        $this->manager->persist($fixture);
        $this->manager->flush();

        $this->client->request('GET', sprintf('%s%s', $this->path, $fixture->getId()));

        self::assertResponseStatusCodeSame(200);
        self::assertPageTitleContains('FoodOrder');

        // Use assertions to check that the properties are properly displayed.
    }

    public function testEdit(): void
    {
        $this->markTestIncomplete();
        $fixture = new FoodOrder;
        $fixture->setCreatedAt('Value');
        $fixture->setClosedAt('Value');
        $fixture->setFoodVendor('Value');

        $this->manager->persist($fixture);
        $this->manager->flush();

        $this->client->request('GET', sprintf('%s%s/edit', $this->path, $fixture->getId()));

        $this->client->submitForm('Update', [
            'food_order[createdAt]' => 'Something New',
            'food_order[closedAt]' => 'Something New',
            'food_order[foodVendor]' => 'Something New',
        ]);

        self::assertResponseRedirects('/food/order/');

        $fixture = $this->repository->findAll();

        self::assertSame('Something New', $fixture[0]->getCreatedAt());
        self::assertSame('Something New', $fixture[0]->getClosedAt());
        self::assertSame('Something New', $fixture[0]->getFoodVendor());
    }

    public function testRemove(): void
    {
        $this->markTestIncomplete();
        $fixture = new FoodOrder;
        $fixture->setCreatedAt('Value');
        $fixture->setClosedAt('Value');
        $fixture->setFoodVendor('Value');

        $this->manager->persist($fixture);
        $this->manager->flush();

        $this->client->request('GET', sprintf('%s%s', $this->path, $fixture->getId()));
        $this->client->submitForm('Delete');

        self::assertResponseRedirects('/food/order/');
        self::assertSame(0, $this->repository->count([]));
    }
}
